@@ -3,7 +3,7 @@ from pathlib import Path
 import click
 
 from nuc_data_tool import __version__
-from nuc_data_tool.anomaly_detection.iforest import save_prediction_to_exel
+from nuc_data_tool.anomaly_detection.train_and_detection import save_prediction_to_exel
 from nuc_data_tool.db.db_utils import init_db
 from nuc_data_tool.db.fetch_data import (fetch_extracted_data_id,
                                          fetch_physical_quantities_by_name,
@@ -261,6 +261,34 @@ def compare(reference_file,
               default=config.get_file_path('result_file_path'),
               type=click.Path(),
               help='输出文件路径，默认读取配置文件中的路径')
+@click.option('--model_type', '-mt',
+              'model_type',
+              default='iforest',
+              type=click.Choice(['abod', 'iforest', 'cluster',
+                                 'cof', 'histogram', 'knn',
+                                 'lof', 'svm', 'pca', 'mcd',
+                                 'sod', 'sos'],
+                                case_sensitive=True),
+              help="""
+‘abod’	Angle-base Outlier Detection
+‘iforest’	Isolation Forest
+‘cluster’	Clustering-Based Local Outlier
+‘cof’	Connectivity-Based Outlier Factor
+‘histogram’	Histogram-based Outlier Detection
+‘knn’	k-Nearest Neighbors Detector
+‘lof’	Local Outlier Factor
+‘svm’	One-class SVM detector
+‘pca’	Principal Component Analysis
+‘mcd’	Minimum Covariance Determinant
+‘sod’	Subspace Outlier Detection
+‘sos	Stochastic Outlier Selection
+""")
+@click.option('--fraction',
+              '-fra',
+              'fraction',
+              type=click.FLOAT,
+              default=0.01,
+              help='异常占数据集的比例，默认0.01')
 @click.option('--model_path', '-mp',
               'model_path',
               default=config.get_anomaly_detection_config('model_path'),
@@ -285,12 +313,16 @@ def compare(reference_file,
               help='将结果合并输出至一个文件')
 def detect(filenames,
            result_path,
+           model_type,
            model_path,
+           fraction,
            physical_quantities,
            is_all_step,
            merge):
     """
-    使用 iforest 对数据进行异常检测，并导出异常的数据至工作簿(xlsx文件)
+    对数据进行异常检测，并导出异常的数据至工作簿(xlsx文件)
+    如果未输入model_type，model_path已输入，
+    则会使用选择的预训练模型进行检测（请务必清楚自己正在干什么）
 
     参数为文件列表(默认为所有文件)
     """
@@ -305,6 +337,8 @@ def detect(filenames,
 
     save_prediction_to_exel(filenames=filenames,
                             result_path=result_path,
+                            model_type=model_type,
+                            fraction=fraction,
                             model_name=model_name,
                             physical_quantities=physical_quantities,
                             is_all_step=is_all_step,
